"""
Execute as:
python -u $O/python/ododo/Scripts/interactive/csv2MacDive.py

Notes
- Set the paths in the last line of the script.
- Can handle up to two buddies.
- Generates a random ID for each dive as required.
- Turns some column values into tags.
- In Excel use the date format: yyyy-mm-dd "12":mm:ss (12 is for missing start times).
"""
from ododo.Libs.DTutils import * #@UnusedWildImport
from ododo.Libs.DBMS import getRelationFromCsvFile

# Regular tags (no spec op needed).
regItems="date country    location    site    maxDepth    duration".split()
# Following columns will be turned into tags
tags="nightdive current warmwater".split()
# Following columns will be turned into buddies
buddies="buddy1 buddy2".split()


def csv2MacDive( dir, inFile, outFile ):
    dTmessage( "Starting csv2MacDive")
    dTmessage( "dir:             %s." % dir )
    dTmessage( "inFile:          %s." % inFile )
    dTmessage( "outFile:         %s." % outFile )
    os.chdir(dir)

    r = getRelationFromCsvFile(inFile)
#     dTmessage( "r is: %s." % r )
    dTmessage( "Found %s rows." % r.sizeRows() )
#     dTexit("ending program prematurely", 1)

#     Start with a header
    xml="""<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<!DOCTYPE dives SYSTEM "http://www.mac-dive.com/macdive_logbook.dtd">

<dives>
    <units>Metric</units>
    <schema>2.0.0</schema>

"""
    sizeRows = r.sizeRows()
#     sizeRows = 1
    for rowIdx in range(sizeRows):
        xml+="<dive>\n"
#         item='date'
#         itemValue=r.getValueByColumnLabel(rowIdx,item)
#         xml+="<%s>%s</%s>\n"                                % (item,itemValue,item)
        xml+="<identifier>%s</identifier>\n"                % getRandomKey(size=30)
        for item in regItems:
            itemValue=r.getValueByColumnLabel(rowIdx,item)
            xml+="<%s>%s</%s>\n"                            % (item,itemValue,item)
        # end for
        notes=r.getValueByColumnLabel(rowIdx,"notes")
        if notes:
            xml+="<notes><![CDATA[%s]]></notes>\n"          % notes
        # end if
        tagList=[]
        for tag in tags:
            tagValue=r.getValueByColumnLabel(rowIdx,tag)
            if tagValue:
                tagList.append(tag)
            # end if
        # end for
        if tagList:
            xml+="<tags>\n"
            for t in tagList:
                xml+="<tag>%s</tag>\n" % t
            # end for
            xml+="</tags>\n"
        buddyList=[]
        for buddy in buddies:
            buddyValue=r.getValueByColumnLabel(rowIdx,buddy)
            if buddyValue:
                buddyList.append(buddyValue)
            # end if
        # end for
        if buddyList:
            xml+="<buddies>\n"
            for b in buddyList:
                xml+="<buddy>%s</buddy>\n" % b
            # end for
            xml+="</buddies>\n"
#         for columnIdx in range(sizeColumns):
#             v = r.getValueString( rowIdx, columnIdx)
        xml+="</dive>\n\n"
    # end for
#     Add a footer
    xml+="\n\n</dives>\n"
    dTmessage( "Writing XML file.")
    writeTextToFile( outFile, xml)
    dTmessage( "Done")
# end def

if __name__ == "__main__":
    csv2MacDive( "/Users/jd/Desktop","myDives.csv","myDives.xml")
